#ifndef NT2_INCLUDE_FUNCTIONS_FAST_COS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FAST_COS_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/fast_cos.hpp>

#endif
